AnnotGoToView

Enum AnnotGoToView 

#[non_exhaustive]
pub enum AnnotGoToView { Fit, Xyz { left: Option<f32>, top: Option<f32>, zoom: Option<f32>, }, FitH { top: Option<f32>, }, FitV { left: Option<f32>, }, FitR { left: f32, bottom: f32, right: f32, top: f32, }, FitB, FitBH { top: Option<f32>, }, FitBV { left: Option<f32>, }, }
Destination view for a AnnotLinkAction::GoTo action.

Mirrors the modes pdfrum_doc::Dest / pdfrum_doc::ZoomMode reads. Optional coordinates of None write PDF null (leave unchanged).

use pdfrum_edit::AnnotGoToView;

assert!(matches!(AnnotGoToView::Fit, AnnotGoToView::Fit));
assert!(matches!(AnnotGoToView::FitH { top: None }, AnnotGoToView::FitH { top: None }));

Variants (Non-exhaustive)

This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.


Fit

Fit the whole page (/Fit).



Xyz

Position at (left, top) with optional zoom (/XYZ).

Fields

left: Option<f32>

Left edge in page space, or unchanged when None.

top: Option<f32>

Top edge in page space, or unchanged when None.

zoom: Option<f32>

Zoom factor, or unchanged when None / Some(0.0).



FitH

Fit the page width; top is the top edge (/FitH).

Fields

top: Option<f32>

Top edge in page space, or unchanged when None.



FitV

Fit the page height; left is the left edge (/FitV).

Fields

left: Option<f32>

Left edge in page space, or unchanged when None.



FitR

Fit the rectangle (/FitR).

Fields

left: f32

Left edge.

bottom: f32

Bottom edge.

right: f32

Right edge.

top: f32

Top edge.



FitB

Fit the bounding box of the page’s contents (/FitB).



FitBH

Fit the bounding box width; top is the top edge (/FitBH).

Fields

top: Option<f32>

Top edge in page space, or unchanged when None.



FitBV

Fit the bounding box height; left is the left edge (/FitBV).

Fields

left: Option<f32>

Left edge in page space, or unchanged when None.